@@ -3,7 +3,7 @@ timelineJSON <- function(time){
   return(toJSON(json))
 }
 
-timeline.create <- function(time, language = c("en","es"), dir = "timeline"){
+timeCreate <- function(time, language = c("en","es"), dir = "timeCoin"){
   if(language[1]=="es")
     language <- "es.js"
   else
@@ -11,13 +11,13 @@ timeline.create <- function(time, language = c("en","es"), dir = "timeline"){
   createHTML(dir, c("reset.css","styles.css"), c("d3.min.js","jspdf.min.js","functions.js",language,"timeline.js"), timelineJSON(time))
 }
 
-timeCoin <- function(nodes, name = "name", start = "start", end = "end", group = NULL, text = NULL, main = NULL, minor = NULL, language = c("en","es"), dir = NULL){
+timeCoin <- function(nodes, name = "name", start = "start", end = "end", group = NULL, text = NULL, main = NULL, note = NULL, language = c("en","es"), dir = NULL){
   options <- list(name=name,start=start,end=end)
   if (!is.null(group)) options[['group']] <- group
   if (!is.null(text)) options[['text']] <- text
   if (!is.null(main)) options[['main']] <- main
-  if (!is.null(minor)) options[['minor']] <- minor
-  time <- structure(list(nodes=nodes,options=options,call=match.call()),class="timeline")
-  if (!is.null(dir)) timeline.create(time,language=language,dir=dir)
+  if (!is.null(note)) options[['note']] <- note
+  time <- structure(list(nodes=nodes,options=options,call=match.call()),class="timeCoin")
+  if (!is.null(dir)) timeCreate(time,language=language,dir=dir)
   return(time)
 }
