@@ -38,13 +38,13 @@ var multiGraph = new MultiGraph();
 window.onload = function(){
   var json = multiGraph.getJSON(window.location.search);
   switch(json[0]){
-    case 'network':
+    case 'netCoin':
       network(json[1]);
       break;
-    case 'barplot':
+    case 'barCoin':
       barplot(json[1]);
       break;
-    case 'timeline':
+    case 'timeCoin':
       timeline(json[1]);
       break;
   }
